@@ -4,6 +4,7 @@ import reciprocalspaceship as rs
 import gemmi
 from pandas.testing import assert_frame_equal
 
+
 def test_constructor_empty():
     """Test DataSet.__init__()"""
     result = rs.DataSet()
@@ -14,11 +15,17 @@ def test_constructor_empty():
 
 @pytest.mark.parametrize("spacegroup", [None, gemmi.SpaceGroup(1)])
 @pytest.mark.parametrize("cell", [None, gemmi.UnitCell(1, 1, 1, 90, 90, 90)])
-def test_constructor_dataset(data_fmodel, spacegroup, cell):
+@pytest.mark.parametrize("merged", [None, True, False])
+def test_constructor_dataset(data_fmodel, spacegroup, cell, merged):
     """Test DataSet.__init__() when called with a DataSet"""
-    result = rs.DataSet(data_fmodel, spacegroup=spacegroup, cell=cell)
+    result = rs.DataSet(data_fmodel, spacegroup=spacegroup, cell=cell, merged=merged)
     assert_frame_equal(result, data_fmodel)
 
+    if merged is not None:
+        assert result.merged == merged
+    else:
+        assert result.merged == True
+        
     # Ensure provided values take precedence
     if spacegroup:
         assert result.spacegroup == spacegroup
@@ -183,7 +190,35 @@ def test_compute_dHKL(dataset_hkl, inplace, cell):
     assert np.allclose(result["dHKL"].to_numpy(), expected)
     assert isinstance(result["dHKL"].dtype, rs.MTZRealDtype)
 
+@pytest.mark.parametrize("bins", [5, 10, 20, 50])
+@pytest.mark.parametrize("inplace", [True, False])
+@pytest.mark.parametrize("return_labels", [True, False])
+def test_assign_resolution_bins(data_fmodel, bins, inplace, return_labels):
+    """Test DataSet.assign_resolution_bins"""
+    
+    result = data_fmodel.assign_resolution_bins(bins=bins,
+                                                inplace=inplace,
+                                                return_labels=return_labels)
 
+    if return_labels:
+        result, labels = result
+        
+    # Test bins
+    assert "bin" in result.columns
+    assert len(result["bin"].unique()) == bins
+    assert result.bin.max() == bins-1
+
+    # Test inplace
+    if inplace:
+        assert id(result) == id(data_fmodel)
+    else:
+        assert id(result) != id(data_fmodel)
+
+    # Test labels
+    if return_labels:
+        assert len(labels) == bins
+
+    
 @pytest.mark.parametrize("inplace", [True, False])
 @pytest.mark.parametrize("op", ["-x,-y,-z",
                                 gemmi.Op("x,y,z"),
@@ -191,6 +226,7 @@ def test_compute_dHKL(dataset_hkl, inplace, cell):
                                 gemmi.Op("x,y,-z"),
                                 gemmi.Op("x,-y,-z"),
                                 gemmi.Op("-x,y,-z"),
+                                5,
 ])
 def test_apply_symop_hkl(data_fmodel, inplace, op):
     """
@@ -201,8 +237,10 @@ def test_apply_symop_hkl(data_fmodel, inplace, op):
 
     copy = data_fmodel.copy()
 
-    if isinstance(op, gemmi.Op):
-
+    if isinstance(op, (gemmi.Op, str)):
+        if isinstance(op, str):
+            op = gemmi.Op(op)
+        
         result = data_fmodel.apply_symop(op, inplace=inplace)
         expectedH = [ op.apply_to_hkl(h) for h in copy.get_hkls() ]
         expectedH = np.array(expectedH)
@@ -329,3 +367,34 @@ def test_canonicalize_phases(data_fmodel, inplace):
     else:
         assert id(result) != id(temp)
 
+
+@pytest.mark.parametrize("sg1", [gemmi.SpaceGroup(96), None])
+@pytest.mark.parametrize("sg2", [gemmi.SpaceGroup(96), gemmi.SpaceGroup(19), None])
+@pytest.mark.parametrize("cell1", [
+    gemmi.UnitCell(78.9, 78.9, 38.1, 90, 90, 90),
+    None
+])
+@pytest.mark.parametrize("cell2", [
+    gemmi.UnitCell(78.97, 78.97, 38.25, 90, 90, 90),
+    gemmi.UnitCell(70.1, 70.1, 38.25, 90, 90, 90),
+    None
+])
+def test_is_isomorphous(data_unmerged, data_fmodel, sg1, sg2, cell1, cell2):
+    """
+    Test DataSet.is_isomorphous() using HEWL data and FMODEL mtz files. 
+    9LYZ is isomorphous, and should return True. 
+    """
+    data_unmerged.spacegroup = sg1
+    data_unmerged.cell = cell1
+    data_fmodel.spacegroup = sg2
+    data_fmodel.cell = cell2
+
+    if (sg1 is None) or (sg2 is None) or (cell1 is None) or (cell2 is None):
+        with pytest.raises(AttributeError):
+            result = data_unmerged.is_isomorphous(data_fmodel)
+    else:
+        result = data_unmerged.is_isomorphous(data_fmodel)
+        if (sg2.number == 96) and (cell2.a == 78.97):
+            assert result
+        else:
+            assert not result
